part of 'reset_password_bloc.dart';

abstract class ResetPasswordEvent extends Equatable {
  const ResetPasswordEvent();

  @override
  List<Object?> get props => [];
}

class ResetPasswordSubmitted extends ResetPasswordEvent {
  final String emailAddress;
  final String newPassword;

  const ResetPasswordSubmitted({
    required this.emailAddress,
    required this.newPassword,
  });

  @override
  List<Object?> get props => [emailAddress, newPassword];
}

class ResetPasswordVisibilityToggled extends ResetPasswordEvent {
  const ResetPasswordVisibilityToggled();
}

class ConfirmPasswordVisibilityToggled extends ResetPasswordEvent {
  const ConfirmPasswordVisibilityToggled();
}

class PasswordChanged extends ResetPasswordEvent {
  final String password;
  const PasswordChanged(this.password);

  @override
  List<Object?> get props => [password];
}

class ResetPasswordErrorToggled extends ResetPasswordEvent {
  final bool show;
  final String? error;
  const ResetPasswordErrorToggled(this.show, {this.error});

  @override
  List<Object?> get props => [show, error];
}

class ResetConfirmPasswordErrorToggled extends ResetPasswordEvent {
  final bool show;
  final String? error;
  const ResetConfirmPasswordErrorToggled(this.show, {this.error});

  @override
  List<Object?> get props => [show, error];
}